@@ -6,8 +6,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef AKREGATOR_BACKEND_STORAGEFACTORYMK4IMPL_H
-#define AKREGATOR_BACKEND_STORAGEFACTORYMK4IMPL_H
+#pragma once
 
 #include "storagefactory.h"
 #include <QString>
@@ -32,4 +31,3 @@ public:
 } // namespace Backend
 } // namespace Akregator
 
-#endif // AKREGATOR_BACKEND_STORAGEFACTORYMK4IMPL_H
