@@ -6,8 +6,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef AKREGATOR_DELETESUBSCRIPTIONCOMMAND_H
-#define AKREGATOR_DELETESUBSCRIPTIONCOMMAND_H
+#pragma once
 
 #include "command.h"
 
@@ -39,4 +38,3 @@ private:
 };
 }
 
-#endif // AKREGATOR_DELETESUBSCRIPTIONCOMMAND_H
