@@ -6,8 +6,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef AKREGATOR_EXPIREITEMSCOMMAND_H
-#define AKREGATOR_EXPIREITEMSCOMMAND_H
+#pragma once
 
 #include "command.h"
 
@@ -42,4 +41,3 @@ private:
 };
 }
 
-#endif // AKREGATOR_EXPIREITEMSCOMMAND_H
